@@ -1,7 +1,22 @@
+"""streamlit-webrtc
+"""
+
 import json
 import logging
 import os
-from typing import Callable, Dict, Hashable, NamedTuple, Optional, TypedDict, Union
+from typing import Callable, Dict, Hashable, NamedTuple, Optional, Union
+
+try:
+    from typing import TypedDict
+except ImportError:
+    # Python < 3.8
+    from typing_extensions import TypedDict
+
+try:
+    import importlib.metadata as importlib_metadata
+except ModuleNotFoundError:
+    # Python < 3.8
+    import importlib_metadata  # type: ignore
 
 import streamlit as st
 import streamlit.components.v1 as components
@@ -16,8 +31,17 @@ from .webrtc import (
     WebRtcWorker,
 )
 
-logger = logging.getLogger(__name__)
-logger.addHandler(logging.NullHandler())
+# Set __version__ dynamically base on metadata.
+# https://github.com/python-poetry/poetry/issues/1036#issuecomment-489880822
+# https://github.com/python-poetry/poetry/issues/144#issuecomment-623927302
+# https://github.com/python-poetry/poetry/pull/2366#issuecomment-652418094
+try:
+    __version__ = importlib_metadata.version(__name__)
+except importlib_metadata.PackageNotFoundError:
+    pass
+
+LOGGER = logging.getLogger(__name__)
+LOGGER.addHandler(logging.NullHandler())
 
 _RELEASE = True  # TODO: How to dynamically manage this variable?
 
@@ -32,19 +56,19 @@ else:
     _component_func = components.declare_component("webrtc_streamer", path=build_dir)
 
 
-session_state = SessionState.get(webrtc_workers={})
+_session_state = SessionState.get(webrtc_workers={})
 
 
-def get_webrtc_worker(key: Hashable) -> Union[WebRtcWorker, None]:
-    return session_state.webrtc_workers.get(key)
+def _get_webrtc_worker(key: Hashable) -> Union[WebRtcWorker, None]:
+    return _session_state.webrtc_workers.get(key)
 
 
-def set_webrtc_worker(key: Hashable, webrtc_worker: WebRtcWorker) -> None:
-    session_state.webrtc_workers[key] = webrtc_worker
+def _set_webrtc_worker(key: Hashable, webrtc_worker: WebRtcWorker) -> None:
+    _session_state.webrtc_workers[key] = webrtc_worker
 
 
-def unset_webrtc_worker(key: Hashable) -> None:
-    del session_state.webrtc_workers[key]
+def _unset_webrtc_worker(key: Hashable) -> None:
+    del _session_state.webrtc_workers[key]
 
 
 class ClientSettings(TypedDict):
@@ -65,7 +89,7 @@ def webrtc_streamer(
     video_transformer_factory: Optional[Callable[[], VideoTransformerBase]] = None,
     async_transform: bool = True,
 ) -> WebRtcWorkerContext:
-    webrtc_worker = get_webrtc_worker(key)
+    webrtc_worker = _get_webrtc_worker(key)
 
     sdp_answer_json = None
     if webrtc_worker:
@@ -90,7 +114,7 @@ def webrtc_streamer(
         if webrtc_worker:
             if not playing:
                 webrtc_worker.stop()
-                unset_webrtc_worker(key)
+                _unset_webrtc_worker(key)
         else:
             if sdp_offer:
                 webrtc_worker = WebRtcWorker(
@@ -100,7 +124,7 @@ def webrtc_streamer(
                     async_transform=async_transform,
                 )
                 webrtc_worker.process_offer(sdp_offer["sdp"], sdp_offer["type"])
-                set_webrtc_worker(key, webrtc_worker)
+                _set_webrtc_worker(key, webrtc_worker)
                 st.experimental_rerun()  # Rerun to send the SDP answer to frontend
 
     ctx = WebRtcWorkerContext(
